@@ -7,9 +7,10 @@ from twisted.internet.ssl import DefaultOpenSSLContextFactory
 from twisted.protocols.basic import LineReceiver
 from twisted.python import log
 
-from vncap.factory import VNCProxy
 from txws import WebSocketFactory
 
+from vncap.vnc.factory import VNCProxy
+
 # Allowed proxy port ranges.
 # By default, this is the VNC port range.
 # To use a different port range, simply change the following two lines.
@@ -30,11 +31,12 @@ class ControlProtocol(LineReceiver):
             sport = d.get("sport")
             ws = d.get("ws", False)
             tls = d.get("tls", False)
+            client_opts = d.get("client", {})
 
             # Allocate the source port.
             sport = self.factory.allocate_port(sport)
 
-            factory = VNCProxy(host, dport, password)
+            factory = VNCProxy(host, dport, password, client_opts)
 
             if ws:
                 factory = WebSocketFactory(factory)
